@@ -6,7 +6,7 @@ use Ref::Util qw/:all/;
 use UNIVERSAL::Object;
 use Data::GUID;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use feature qw/switch/;
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
@@ -30,7 +30,8 @@ BEGIN {
       aria_disabled aria_dropeffect aria_flowto aria_grabbed aria_expanded aria_haspopup aria_hidden
       aria_invalid aria_label aria_labelledby aria_live aria_level aria_multiline aria_multiselectable
       aria_orientation aria_pressed aria_readonly aria_required aria_selected aria_sort aria_valuemax
-      aria_valuemin aria_valuenow aria_valuetext aria_owns aria_relevant role data_toggle data_target aria_describedby/;
+      aria_valuemin aria_valuenow aria_valuetext aria_owns aria_relevant role data_toggle data_target 
+      aria_describedby onkeydown onclick/;
 
     %HAS = (
         (
@@ -222,7 +223,7 @@ Moonshine::Element - Build some more html.
 
 =head1 VERSION
 
-Version 0.06 
+Version 0.07 
 
 =head1 DESCRIPTION
 
